summaryrefslogtreecommitdiffstats
path: root/src/engine/SCons/Scanner/FortranTests.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/engine/SCons/Scanner/FortranTests.py')
-rw-r--r--src/engine/SCons/Scanner/FortranTests.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/engine/SCons/Scanner/FortranTests.py b/src/engine/SCons/Scanner/FortranTests.py
index 82db694..ff63bda 100644
--- a/src/engine/SCons/Scanner/FortranTests.py
+++ b/src/engine/SCons/Scanner/FortranTests.py
@@ -364,7 +364,7 @@ class FortranScannerTestCase9(unittest.TestCase):
deps = s(n, env, path)
# Make sure rexists() got called on the file node being
# scanned, essential for cooperation with BuildDir functionality.
assert n.rexists_called
headers = ['d1/f3.f', 'f3.f']
@@ -441,8 +441,8 @@ class FortranScannerTestCase14(unittest.TestCase):
def runTest(self):
os.chdir(test.workpath('work'))
fs = SCons.Node.FS.FS(test.workpath('work'))
- fs.BuildDir('build1', 'src', 1)
- fs.BuildDir('build2', 'src', 0)
+ fs.VariantDir('build1', 'src', 1)
+ fs.VariantDir('build2', 'src', 0)
fs.Repository(test.workpath('repository'))
env = DummyEnvironment([])
env.fs = fs
@@ -364,7 +364,7 @@ class FortranScannerTestCase9(unittest.TestCase):
deps = s(n, env, path)
# Make sure rexists() got called on the file node being
- # scanned, essential for cooperation with BuildDir functionality.
+ # scanned, essential for cooperation with VariantDir functionality.
assert n.rexists_called
headers = ['d1/f3.f', 'f3.f']